@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.87'; # VERSION
+our $VERSION = '1.88'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -155,11 +155,16 @@ sub configure
   $self->add_plugins(qw(
 
     InstallGuide
-    MinimumPerl
     ConfirmRelease
 
   ));
   
+  $self->add_plugins([
+    MinimumPerl => {
+      maybe perl => $self->payload->{perl},
+    },
+  ]);
+
   unless($self->payload->{no_readme})
   {
     $self->add_plugins([
@@ -262,7 +267,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.87
+version 1.88
 
 =head1 SYNOPSIS
 
@@ -357,8 +362,8 @@ This plugin bundle is mostly equivalent to
  repository.web = https://github.com/plicease/My-Dist
  
  [InstallGuide]
- [MinimumPerl]
  [ConfirmRelease]
+ [MinimumPerl]
  
  [ReadmeAnyFromPod]
  filename = README
@@ -466,6 +471,10 @@ becomes formally supported).
 
 Specify an alternative to OurPkgVersion for updating the versions in .pm files.
 
+=head2 perl
+
+Specify a minimum Perl version.  If not specified it will be detected.
+
 =head1 SEE ALSO
 
 =over 4
